@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Connection module for Amazon CloudWatch
 
 .. versionadded:: 2014.7.0
@@ -40,60 +39,57 @@ Connection module for Amazon CloudWatch
             region: us-east-1
 
 :depends: boto
-'''
+"""
 # keep lint from choking on _get_conn and _cache_id
-#pylint: disable=E0602
+# pylint: disable=E0602
 
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import Python libs
 import logging
-import yaml  # pylint: disable=blacklisted-import
 
-# Import Salt libs
-from salt.ext import six
 import salt.utils.json
 import salt.utils.odict as odict
 import salt.utils.versions
+import yaml  # pylint: disable=blacklisted-import
 
-log = logging.getLogger(__name__)
-
-# Import third party libs
 try:
     import boto
     import boto.ec2.cloudwatch
     import boto.ec2.cloudwatch.listelement
     import boto.ec2.cloudwatch.dimension
-    logging.getLogger('boto').setLevel(logging.CRITICAL)
+
+    logging.getLogger("boto").setLevel(logging.CRITICAL)
     HAS_BOTO = True
 except ImportError:
     HAS_BOTO = False
 
+log = logging.getLogger(__name__)
+
 
 def __virtual__():
-    '''
+    """
     Only load if boto libraries exist.
-    '''
+    """
     has_boto_reqs = salt.utils.versions.check_boto_reqs(check_boto3=False)
     if has_boto_reqs is True:
-        __utils__['boto.assign_funcs'](__name__, 'cloudwatch',
-                                       module='ec2.cloudwatch',
-                                       pack=__salt__)
+        __utils__["boto.assign_funcs"](
+            __name__, "cloudwatch", module="ec2.cloudwatch", pack=__salt__
+        )
     return has_boto_reqs
 
 
 def get_alarm(name, region=None, key=None, keyid=None, profile=None):
-    '''
+    """
     Get alarm details. Also can be used to check to see if an alarm exists.
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_cloudwatch.get_alarm myalarm region=us-east-1
-    '''
+    """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
 
     alarms = conn.describe_alarms(alarm_names=[name])
-    if len(alarms) == 0:
+    if not alarms:
         return None
     if len(alarms) > 1:
         log.error("multiple alarms matched name '%s'", name)
@@ -101,32 +97,36 @@ def get_alarm(name, region=None, key=None, keyid=None, profile=None):
 
 
 def _safe_dump(data):
-    '''
+    """
     this presenter magic makes yaml.safe_dump
     work with the objects returned from
     boto.describe_alarms()
-    '''
-    custom_dumper = __utils__['yaml.get_dumper']('SafeOrderedDumper')
+    """
+    custom_dumper = __utils__["yaml.get_dumper"]("SafeOrderedDumper")
 
     def boto_listelement_presenter(dumper, data):
         return dumper.represent_list(list(data))
 
-    yaml.add_representer(boto.ec2.cloudwatch.listelement.ListElement,
-                         boto_listelement_presenter,
-                         Dumper=custom_dumper)
+    yaml.add_representer(
+        boto.ec2.cloudwatch.listelement.ListElement,
+        boto_listelement_presenter,
+        Dumper=custom_dumper,
+    )
 
     def dimension_presenter(dumper, data):
         return dumper.represent_dict(dict(data))
 
-    yaml.add_representer(boto.ec2.cloudwatch.dimension.Dimension,
-                         dimension_presenter, Dumper=custom_dumper)
+    yaml.add_representer(
+        boto.ec2.cloudwatch.dimension.Dimension,
+        dimension_presenter,
+        Dumper=custom_dumper,
+    )
 
-    return __utils__['yaml.dump'](data, Dumper=custom_dumper)
+    return __utils__["yaml.dump"](data, Dumper=custom_dumper)
 
 
-def get_all_alarms(region=None, prefix=None, key=None, keyid=None,
-                   profile=None):
-    '''
+def get_all_alarms(region=None, prefix=None, key=None, keyid=None, profile=None):
+    """
     Get all alarm details.  Produces results that can be used to create an sls
     file.
 
@@ -153,10 +153,12 @@ def get_all_alarms(region=None, prefix=None, key=None, keyid=None,
             $ salt-call boto_cloudwatch.get_all_alarms --out=txt | sed "s/local: //" > final_alarms.sls
             $ diff final_alarms.sls managed_alarms.sls
 
-    CLI example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_cloudwatch.get_all_alarms region=us-east-1 --out=txt
-    '''
+    """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
 
     alarms = conn.describe_alarms()
@@ -170,19 +172,32 @@ def get_all_alarms(region=None, prefix=None, key=None, keyid=None,
             name = prefix + alarm["name"]
         del alarm["name"]
         alarm_sls = [{"name": name}, {"attributes": alarm}]
-        results["manage alarm " + name] = {"boto_cloudwatch_alarm.present":
-                                           alarm_sls}
+        results["manage alarm " + name] = {"boto_cloudwatch_alarm.present": alarm_sls}
     return _safe_dump(results)
 
 
 def create_or_update_alarm(
-        connection=None, name=None, metric=None, namespace=None,
-        statistic=None, comparison=None, threshold=None, period=None,
-        evaluation_periods=None, unit=None, description='',
-        dimensions=None, alarm_actions=None,
-        insufficient_data_actions=None, ok_actions=None,
-        region=None, key=None, keyid=None, profile=None):
-    '''
+    connection=None,
+    name=None,
+    metric=None,
+    namespace=None,
+    statistic=None,
+    comparison=None,
+    threshold=None,
+    period=None,
+    evaluation_periods=None,
+    unit=None,
+    description="",
+    dimensions=None,
+    alarm_actions=None,
+    insufficient_data_actions=None,
+    ok_actions=None,
+    region=None,
+    key=None,
+    keyid=None,
+    profile=None,
+):
+    """
     Create or update a cloudwatch alarm.
 
     Params are the same as:
@@ -204,10 +219,12 @@ def create_or_update_alarm(
     boto_cloudwatch_alarm.present states which have alarm_actions that
     reference the scaling_policy.
 
-    CLI example:
+    CLI Example:
+
+    .. code-block:: bash
 
         salt myminion boto_cloudwatch.create_alarm name=myalarm ... region=us-east-1
-    '''
+    """
     # clean up argument types, so that CLI works
     if threshold:
         threshold = float(threshold)
@@ -215,37 +232,39 @@ def create_or_update_alarm(
         period = int(period)
     if evaluation_periods:
         evaluation_periods = int(evaluation_periods)
-    if isinstance(dimensions, six.string_types):
+    if isinstance(dimensions, str):
         dimensions = salt.utils.json.loads(dimensions)
         if not isinstance(dimensions, dict):
-            log.error("could not parse dimensions argument: must be json encoding of a dict: '%s'", dimensions)
+            log.error(
+                "could not parse dimensions argument: must be json encoding of a dict:"
+                " '%s'",
+                dimensions,
+            )
             return False
-    if isinstance(alarm_actions, six.string_types):
+    if isinstance(alarm_actions, str):
         alarm_actions = alarm_actions.split(",")
-    if isinstance(insufficient_data_actions, six.string_types):
+    if isinstance(insufficient_data_actions, str):
         insufficient_data_actions = insufficient_data_actions.split(",")
-    if isinstance(ok_actions, six.string_types):
+    if isinstance(ok_actions, str):
         ok_actions = ok_actions.split(",")
 
     # convert provided action names into ARN's
     if alarm_actions:
-        alarm_actions = convert_to_arn(alarm_actions,
-                                       region=region,
-                                       key=key,
-                                       keyid=keyid,
-                                       profile=profile)
+        alarm_actions = convert_to_arn(
+            alarm_actions, region=region, key=key, keyid=keyid, profile=profile
+        )
     if insufficient_data_actions:
-        insufficient_data_actions = convert_to_arn(insufficient_data_actions,
-                                                   region=region,
-                                                   key=key,
-                                                   keyid=keyid,
-                                                   profile=profile)
+        insufficient_data_actions = convert_to_arn(
+            insufficient_data_actions,
+            region=region,
+            key=key,
+            keyid=keyid,
+            profile=profile,
+        )
     if ok_actions:
-        ok_actions = convert_to_arn(ok_actions,
-                                    region=region,
-                                    key=key,
-                                    keyid=keyid,
-                                    profile=profile)
+        ok_actions = convert_to_arn(
+            ok_actions, region=region, key=key, keyid=keyid, profile=profile
+        )
 
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
 
@@ -264,22 +283,24 @@ def create_or_update_alarm(
         dimensions=dimensions,
         alarm_actions=alarm_actions,
         insufficient_data_actions=insufficient_data_actions,
-        ok_actions=ok_actions
+        ok_actions=ok_actions,
     )
     conn.create_alarm(alarm)
-    log.info('Created/updated alarm %s', name)
+    log.info("Created/updated alarm %s", name)
     return True
 
 
 def convert_to_arn(arns, region=None, key=None, keyid=None, profile=None):
-    '''
+    """
     Convert a list of strings into actual arns. Converts convenience names such
     as 'scaling_policy:...'
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' convert_to_arn 'scaling_policy:'
-    '''
+    """
     results = []
     for arn in arns:
         if arn.startswith("scaling_policy:"):
@@ -290,37 +311,49 @@ def convert_to_arn(arns, region=None, key=None, keyid=None, profile=None):
             if policy_arn:
                 results.append(policy_arn)
             else:
-                log.error('Could not convert: %s', arn)
+                log.error("Could not convert: %s", arn)
         else:
             results.append(arn)
     return results
 
 
 def delete_alarm(name, region=None, key=None, keyid=None, profile=None):
-    '''
+    """
     Delete a cloudwatch alarm
 
     CLI example to delete a queue::
 
         salt myminion boto_cloudwatch.delete_alarm myalarm region=us-east-1
-    '''
+    """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
 
     conn.delete_alarms([name])
-    log.info('Deleted alarm %s', name)
+    log.info("Deleted alarm %s", name)
     return True
 
 
 def _metric_alarm_to_dict(alarm):
-    '''
+    """
     Convert a boto.ec2.cloudwatch.alarm.MetricAlarm into a dict. Convenience
     for pretty printing.
-    '''
+    """
     d = odict.OrderedDict()
-    fields = ['name', 'metric', 'namespace', 'statistic', 'comparison',
-              'threshold', 'period', 'evaluation_periods', 'unit',
-              'description', 'dimensions', 'alarm_actions',
-              'insufficient_data_actions', 'ok_actions']
+    fields = [
+        "name",
+        "metric",
+        "namespace",
+        "statistic",
+        "comparison",
+        "threshold",
+        "period",
+        "evaluation_periods",
+        "unit",
+        "description",
+        "dimensions",
+        "alarm_actions",
+        "insufficient_data_actions",
+        "ok_actions",
+    ]
     for f in fields:
         if hasattr(alarm, f):
             d[f] = getattr(alarm, f)
