@@ -3,6 +3,7 @@
 Define some generic socket functions for network modules
 """
 
+
 import fnmatch
 import itertools
 import logging
@@ -10,6 +11,7 @@ import os
 import platform
 import random
 import re
+import shutil
 import socket
 import subprocess
 import types
@@ -46,18 +48,25 @@ except (ImportError, OSError, AttributeError, TypeError):
     pass
 
 
-_INTERFACES = {}
+class Interfaces:
+    __slots__ = ("interfaces",)
+
+    def __init__(self, interfaces=None):
+        if interfaces is None:
+            interfaces = {}
+        self.interfaces = interfaces
+
+    def __call__(self, *args, **kwargs):
+        if not self.interfaces:
+            self.interfaces = interfaces()
+        return self.interfaces
+
+    def clear(self):
+        self.interfaces = {}
 
 
-def _get_interfaces():
-    """
-    Provide a dict of the connected interfaces and their ip addresses
-    """
-
-    global _INTERFACES
-    if not _INTERFACES:
-        _INTERFACES = interfaces()
-    return _INTERFACES
+_get_interfaces = Interfaces()
+_clear_interfaces = _get_interfaces.clear
 
 
 def sanitize_host(host):
@@ -735,12 +744,12 @@ def _interfaces_ip(out):
                 type_, value = tuple(cols[0:2])
                 iflabel = cols[-1:][0]
                 if type_ in ("inet", "inet6"):
+                    ipaddr, netmask, broadcast, scope = parse_network(value, cols)
+                    addr_obj = dict()
                     if "secondary" not in cols:
-                        ipaddr, netmask, broadcast, scope = parse_network(value, cols)
                         if type_ == "inet":
                             if "inet" not in data:
                                 data["inet"] = list()
-                            addr_obj = dict()
                             addr_obj["address"] = ipaddr
                             addr_obj["netmask"] = netmask
                             addr_obj["broadcast"] = broadcast
@@ -749,25 +758,28 @@ def _interfaces_ip(out):
                         elif type_ == "inet6":
                             if "inet6" not in data:
                                 data["inet6"] = list()
-                            addr_obj = dict()
                             addr_obj["address"] = ipaddr
                             addr_obj["prefixlen"] = netmask
                             addr_obj["scope"] = scope
                             data["inet6"].append(addr_obj)
                     else:
-                        if "secondary" not in data:
-                            data["secondary"] = list()
-                        ip_, mask, brd, scp = parse_network(value, cols)
-                        data["secondary"].append(
-                            {
-                                "type": type_,
-                                "address": ip_,
-                                "netmask": mask,
-                                "broadcast": brd,
-                                "label": iflabel,
-                            }
-                        )
-                        del ip_, mask, brd, scp
+                        if type_ == "inet":
+                            if "secondary" not in data:
+                                data["secondary"] = list()
+                            addr_obj["type"] = type_
+                            addr_obj["address"] = ipaddr
+                            addr_obj["netmask"] = netmask
+                            addr_obj["broadcast"] = broadcast
+                            addr_obj["label"] = iflabel
+                            data["secondary"].append(addr_obj)
+                        elif type_ == "inet6":
+                            if "secondary" not in data:
+                                data["secondary"] = list()
+                            addr_obj["type"] = type_
+                            addr_obj["address"] = ipaddr
+                            addr_obj["prefixlen"] = netmask
+                            addr_obj["scope"] = scope
+                            data["secondary"].append(addr_obj)
                 elif type_.startswith("link"):
                     data["hwaddr"] = value
         if iface:
@@ -793,7 +805,8 @@ def _interfaces_ifconfig(out):
         pip = re.compile(r".*?(?:inet addr:|inet [^\d]*)(.*?)\s")
         pip6 = re.compile(".*?(?:inet6 addr: (.*?)/|inet6 )([0-9a-fA-F:]+)")
         pmask6 = re.compile(
-            r".*?(?:inet6 addr: [0-9a-fA-F:]+/(\d+)|prefixlen (\d+))(?: Scope:([a-zA-Z]+)| scopeid (0x[0-9a-fA-F]))?"
+            r".*?(?:inet6 addr: [0-9a-fA-F:]+/(\d+)|prefixlen (\d+))(?:"
+            r" Scope:([a-zA-Z]+)| scopeid (0x[0-9a-fA-F]))?"
         )
     pmask = re.compile(r".*?(?:Mask:|netmask )(?:((?:0x)?[0-9a-fA-F]{8})|([\d\.]+))")
     pupdown = re.compile("UP")
@@ -914,7 +927,9 @@ def linux_interfaces():
         )
     elif ifconfig_path:
         cmd = subprocess.Popen(
-            [ifconfig_path, "-a"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
+            [ifconfig_path, "-a"],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
         ).communicate()[0]
         ifaces = _interfaces_ifconfig(salt.utils.stringutils.to_str(cmd))
     return ifaces
@@ -991,10 +1006,11 @@ def _junos_interfaces_ifconfig(out):
     pmac = re.compile("curr media .*? ([0-9a-f:]+)")
 
     pip = re.compile(
-        r".*?inet\s*(primary)*\s+mtu (\d+)\s+local=[^\d]*(.*?)\s+dest=[^\d]*(.*?)\/([\d]*)\s+bcast=((?:[0-9]{1,3}\.){3}[0-9]{1,3})"
+        r".*?inet\s*(primary)*\s+mtu"
+        r" (\d+)\s+local=[^\d]*(.*?)\s{0,40}dest=[^\d]*(.*?)\/([\d]*)\s{0,40}bcast=((?:[0-9]{1,3}\.){3}[0-9]{1,3})"
     )
     pip6 = re.compile(
-        r".*?inet6 mtu [^\d]+\s+local=([0-9a-f:]+)%([a-zA-Z0-9]*)/([\d]*)\s"
+        r".*?inet6 mtu [^\d]+\s{0,40}local=([0-9a-f:]+)%([a-zA-Z0-9]*)/([\d]*)\s"
     )
 
     pupdown = re.compile("UP")
@@ -1057,7 +1073,9 @@ def junos_interfaces():
     """
     ifconfig_path = salt.utils.path.which("ifconfig")
     cmd = subprocess.Popen(
-        [ifconfig_path, "-a"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
+        [ifconfig_path, "-a"],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
     ).communicate()[0]
     return _junos_interfaces_ifconfig(salt.utils.stringutils.to_str(cmd))
 
@@ -1074,7 +1092,9 @@ def netbsd_interfaces():
 
     ifconfig_path = salt.utils.path.which("ifconfig")
     cmd = subprocess.Popen(
-        [ifconfig_path, "-a"], stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
+        [ifconfig_path, "-a"],
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
     ).communicate()[0]
     return _netbsd_interfaces_ifconfig(salt.utils.stringutils.to_str(cmd))
 
@@ -1203,7 +1223,7 @@ def _get_iface_info(iface):
     if iface in iface_info.keys():
         return iface_info, False
     else:
-        error_msg = 'Interface "{}" not in available interfaces: "{}"' "".format(
+        error_msg = 'Interface "{}" not in available interfaces: "{}"'.format(
             iface, '", "'.join(iface_info.keys())
         )
         log.error(error_msg)
@@ -1218,7 +1238,9 @@ def _hw_addr_aix(iface):
     cmd = subprocess.Popen(
         ["grep", "Hardware Address"],
         stdin=subprocess.Popen(
-            ["entstat", "-d", iface], stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
+            ["entstat", "-d", iface],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
         ).stdout,
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
@@ -1701,8 +1723,13 @@ def _netlink_tool_remote_on(port, which_end):
         elif "ESTAB" not in line:
             continue
         chunks = line.split()
+        local_host, local_port = chunks[3].rsplit(":", 1)
         remote_host, remote_port = chunks[4].rsplit(":", 1)
 
+        if which_end == "remote_port" and int(remote_port) != int(port):
+            continue
+        if which_end == "local_port" and int(local_port) != int(port):
+            continue
         remotes.add(remote_host.strip("[]"))
 
     if valid is False:
@@ -1970,11 +1997,14 @@ def _linux_remotes_on(port, which_end):
 
     """
     remotes = set()
+    lsof_binary = shutil.which("lsof")
+    if lsof_binary is None:
+        return remotes
 
     try:
         data = subprocess.check_output(
             [
-                "lsof",
+                lsof_binary,
                 "-iTCP:{:d}".format(port),
                 "-n",
                 "-P",
@@ -2142,26 +2172,47 @@ def dns_check(addr, port, safe=False, ipv6=None):
         if ipv6 is False
         else socket.AF_UNSPEC
     )
+    socket_error = False
     try:
         refresh_dns()
         addrinfo = socket.getaddrinfo(addr, port, family, socket.SOCK_STREAM)
         ip_addrs = _test_addrs(addrinfo, port)
     except TypeError:
-        err = (
-            "Attempt to resolve address '{}' failed. Invalid or unresolveable address"
-        ).format(addr)
-        raise SaltSystemExit(code=42, msg=err)
+        raise SaltSystemExit(
+            code=42,
+            msg=(
+                "Attempt to resolve address '{}' failed. Invalid or unresolveable"
+                " address".format(addr)
+            ),
+        )
     except OSError:
-        pass
+        socket_error = True
+
+    # If ipv6 is set to True, attempt another lookup using the IPv4 family,
+    # just in case we're attempting to lookup an IPv4 IP
+    # as an IPv6 hostname.
+    if socket_error and ipv6:
+        try:
+            refresh_dns()
+            addrinfo = socket.getaddrinfo(
+                addr, port, socket.AF_INET, socket.SOCK_STREAM
+            )
+            ip_addrs = _test_addrs(addrinfo, port)
+        except TypeError:
+            raise SaltSystemExit(
+                code=42,
+                msg=(
+                    "Attempt to resolve address '{}' failed. Invalid or unresolveable"
+                    " address".format(addr)
+                ),
+            )
+        except OSError:
+            error = True
 
     if not ip_addrs:
-        err = ("DNS lookup or connection check of '{}' failed.").format(addr)
+        err = "DNS lookup or connection check of '{}' failed.".format(addr)
         if safe:
-            if salt.log.is_console_configured():
-                # If logging is not configured it also means that either
-                # the master or minion instance calling this hasn't even
-                # started running
-                log.error(err)
+            log.error(err)
             raise SaltClientError()
         raise SaltSystemExit(code=42, msg=err)
 
@@ -2232,16 +2283,11 @@ def parse_host_port(host_port):
             try:
                 port = int(port)
             except ValueError as _e_:
-                log.error(
-                    'host_port "{}" port value "{}" is not an integer.'.format(
-                        host_port, port
-                    )
-                )
-                raise ValueError(
-                    'host_port "{}" port value "{}" is not an integer.'.format(
-                        host_port, port
-                    )
+                errmsg = 'host_port "{}" port value "{}" is not an integer.'.format(
+                    host_port, port
                 )
+                log.error(errmsg)
+                raise ValueError(errmsg)
         else:
             host = _s_
     try:
