@@ -10,11 +10,13 @@ documented in the execution module docs.
 import base64
 import logging
 import os
+import tempfile
 import time
 
 import requests
 import salt.crypt
 import salt.exceptions
+import salt.utils.json
 import salt.utils.versions
 
 log = logging.getLogger(__name__)
@@ -84,13 +86,11 @@ def _get_token_and_url_from_master():
         )
         raise salt.exceptions.CommandExecutionError(result)
     if not isinstance(result, dict):
-        log.error(
-            "Failed to get token from master! " "Response is not a dict: %s", result
-        )
+        log.error("Failed to get token from master! Response is not a dict: %s", result)
         raise salt.exceptions.CommandExecutionError(result)
     if "error" in result:
         log.error(
-            "Failed to get token from master! " "An error was returned: %s",
+            "Failed to get token from master! An error was returned: %s",
             result["error"],
         )
         raise salt.exceptions.CommandExecutionError(result)
@@ -103,6 +103,7 @@ def _get_token_and_url_from_master():
         "url": result["url"],
         "token": result["token"],
         "verify": result.get("verify", None),
+        "namespace": result.get("namespace"),
         "uses": result.get("uses", 1),
         "lease_duration": result["lease_duration"],
         "issued": result["issued"],
@@ -117,6 +118,8 @@ def get_vault_connection():
 
     def _use_local_config():
         log.debug("Using Vault connection details from local config")
+        # Vault Enterprise requires a namespace
+        namespace = __opts__["vault"].get("namespace")
         try:
             if __opts__["vault"]["auth"]["method"] == "approle":
                 verify = __opts__["vault"].get("verify", None)
@@ -127,7 +130,13 @@ def get_vault_connection():
                     payload = {"role_id": __opts__["vault"]["auth"]["role_id"]}
                     if "secret_id" in __opts__["vault"]["auth"]:
                         payload["secret_id"] = __opts__["vault"]["auth"]["secret_id"]
-                    response = requests.post(url, json=payload, verify=verify)
+                    if namespace is not None:
+                        headers = {"X-Vault-Namespace": namespace}
+                        response = requests.post(
+                            url, headers=headers, json=payload, verify=verify
+                        )
+                    else:
+                        response = requests.post(url, json=payload, verify=verify)
                     if response.status_code != 200:
                         errmsg = "An error occurred while getting a token from approle"
                         raise salt.exceptions.CommandExecutionError(errmsg)
@@ -139,6 +148,8 @@ def get_vault_connection():
                 if _wrapped_token_valid():
                     url = "{}/v1/sys/wrapping/unwrap".format(__opts__["vault"]["url"])
                     headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
+                    if namespace is not None:
+                        headers["X-Vault-Namespace"] = namespace
                     response = requests.post(url, headers=headers, verify=verify)
                     if response.status_code != 200:
                         errmsg = "An error occured while unwrapping vault token"
@@ -148,6 +159,7 @@ def get_vault_connection():
                     ]
             return {
                 "url": __opts__["vault"]["url"],
+                "namespace": namespace,
                 "token": __opts__["vault"]["auth"]["token"],
                 "verify": __opts__["vault"].get("verify", None),
                 "issued": int(round(time.time())),
@@ -217,7 +229,7 @@ def write_cache(connection):
         # Must have been passed metadata. This is already handled by _get_secret_path_metadata
         #  and does not need to be resaved
         return True
-
+    temp_fp, temp_file = tempfile.mkstemp(dir=__opts__["cachedir"])
     cache_file = os.path.join(__opts__["cachedir"], "salt_vault_token")
     try:
         log.debug("Writing vault cache file")
@@ -226,8 +238,11 @@ def write_cache(connection):
             connection["unlimited_use_token"] = True
         else:
             connection["unlimited_use_token"] = False
-        with salt.utils.files.fpopen(cache_file, "w", mode=0o600) as fp_:
+        with salt.utils.files.fpopen(temp_file, "w", mode=0o600) as fp_:
             fp_.write(salt.utils.json.dumps(connection))
+        os.close(temp_fp)
+        # Atomic operation to pervent race condition with concurrent calls.
+        os.rename(temp_file, cache_file)
         return True
     except OSError:
         log.error(
@@ -274,11 +289,11 @@ def get_cache():
 
     # Determine if ttl still valid
     if ttl10 < cur_time:
-        log.debug("Cached token has expired {} < {}: DELETING".format(ttl10, cur_time))
+        log.debug("Cached token has expired %s < %s: DELETING", ttl10, cur_time)
         del_cache()
         return _gen_new_connection()
     else:
-        log.debug("Token has not expired {} > {}".format(ttl10, cur_time))
+        log.debug("Token has not expired %s > %s", ttl10, cur_time)
     return connection
 
 
@@ -287,6 +302,7 @@ def make_request(
     resource,
     token=None,
     vault_url=None,
+    namespace=None,
     get_token_url=False,
     retry=False,
     **args
@@ -300,6 +316,7 @@ def make_request(
         connection = get_cache()
     token = connection["token"] if not token else token
     vault_url = connection["url"] if not vault_url else vault_url
+    namespace = namespace or connection.get("namespace")
     if "verify" in args:
         args["verify"] = args["verify"]
     else:
@@ -310,6 +327,8 @@ def make_request(
             pass
     url = "{}/{}".format(vault_url, resource)
     headers = {"X-Vault-Token": str(token), "Content-Type": "application/json"}
+    if namespace is not None:
+        headers["X-Vault-Namespace"] = namespace
     response = requests.request(method, url, headers=headers, **args)
     if not response.ok and response.json().get("errors", None) == ["permission denied"]:
         log.info("Permission denied from vault")
@@ -348,7 +367,7 @@ def make_request(
                 log.debug("Deleting token from memory")
                 del __context__["vault_token"]
         else:
-            log.debug("Token has {} uses left".format(connection["uses"]))
+            log.debug("Token has %s uses left", connection["uses"])
             write_cache(connection)
 
     if get_token_url:
@@ -363,10 +382,14 @@ def _selftoken_expired():
     """
     try:
         verify = __opts__["vault"].get("verify", None)
+        # Vault Enterprise requires a namespace
+        namespace = __opts__["vault"].get("namespace")
         url = "{}/v1/auth/token/lookup-self".format(__opts__["vault"]["url"])
         if "token" not in __opts__["vault"]["auth"]:
             return True
         headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
+        if namespace is not None:
+            headers["X-Vault-Namespace"] = namespace
         response = requests.get(url, headers=headers, verify=verify)
         if response.status_code != 200:
             return True
@@ -383,10 +406,14 @@ def _wrapped_token_valid():
     """
     try:
         verify = __opts__["vault"].get("verify", None)
+        # Vault Enterprise requires a namespace
+        namespace = __opts__["vault"].get("namespace")
         url = "{}/v1/sys/wrapping/lookup".format(__opts__["vault"]["url"])
         if "token" not in __opts__["vault"]["auth"]:
             return False
         headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
+        if namespace is not None:
+            headers["X-Vault-Namespace"] = namespace
         response = requests.post(url, headers=headers, verify=verify)
         if response.status_code != 200:
             return False
@@ -439,8 +466,10 @@ def _v2_the_path(path, pfilter, ptype="data"):
     """
     possible_types = ["data", "metadata", "destroy"]
     assert ptype in possible_types
-    msg = "Path {} already contains {} in the right place - saltstack duct tape?".format(
-        path, ptype
+    msg = (
+        "Path {} already contains {} in the right place - saltstack duct tape?".format(
+            path, ptype
+        )
     )
 
     path = path.rstrip("/").lstrip("/")
